# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class AtlasClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateProblem(self, request, **kwargs):
        path = "/problems"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateProblemOutput"),
            **kwargs,
        )

    def DeleteProblem(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteProblemOutput"),
            **kwargs,
        )

    def ListProblems(self, request, **kwargs):
        path = "/problems"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListProblemsOutput"),
            **kwargs,
        )

    def VoteProblem(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/vote"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.VoteProblemOutput"),
            **kwargs,
        )

    def DescribeProblem(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeProblemOutput"),
            **kwargs,
        )

    def UpdateProblem(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateProblemOutput"),
            **kwargs,
        )

    def SyncProblem(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/sync"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.SyncProblemOutput"),
            **kwargs,
        )

    def SetBookmark(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/bookmark"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.SetBookmarkOutput"),
            **kwargs,
        )

    def GetBookmark(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/bookmark"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.GetBookmarkOutput"),
            **kwargs,
        )

    def ListExamples(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/examples"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListExamplesOutput"),
            **kwargs,
        )

    def UpdateTestingConfig(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testing"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateTestingConfigOutput"),
            **kwargs,
        )

    def DescribeTestingConfig(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testing"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeTestingConfigOutput"),
            **kwargs,
        )

    def UpdateChecker(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/checker"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateCheckerOutput"),
            **kwargs,
        )

    def DescribeChecker(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/checker"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeCheckerOutput"),
            **kwargs,
        )

    def UpdateInteractor(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/interactor"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateInteractorOutput"),
            **kwargs,
        )

    def DescribeInteractor(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/interactor"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeInteractorOutput"),
            **kwargs,
        )

    def CreateStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateStatementOutput"),
            **kwargs,
        )

    def UpdateStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.statement_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateStatementOutput"),
            **kwargs,
        )

    def DeleteStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.statement_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteStatementOutput"),
            **kwargs,
        )

    def ListStatements(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListStatementsOutput"),
            **kwargs,
        )

    def DescribeStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/statements/"+urllib.parse.quote(request.statement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.statement_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeStatementOutput"),
            **kwargs,
        )

    def LookupStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/translate"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.LookupStatementOutput"),
            **kwargs,
        )

    def PreviewStatement(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/renders"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.PreviewStatementOutput"),
            **kwargs,
        )

    def CreateTestset(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateTestsetOutput"),
            **kwargs,
        )

    def UpdateTestset(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateTestsetOutput"),
            **kwargs,
        )

    def DeleteTestset(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteTestsetOutput"),
            **kwargs,
        )

    def ListTestsets(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListTestsetsOutput"),
            **kwargs,
        )

    def DescribeTestset(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeTestsetOutput"),
            **kwargs,
        )

    def CreateTest(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateTestOutput"),
            **kwargs,
        )

    def UpdateTest(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateTestOutput"),
            **kwargs,
        )

    def DeleteTest(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteTestOutput"),
            **kwargs,
        )

    def ListTests(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListTestsOutput"),
            **kwargs,
        )

    def DescribeTest(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeTestOutput"),
            **kwargs,
        )

    def CreateCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateCodeTemplateOutput"),
            **kwargs,
        )

    def UpdateCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates/"+urllib.parse.quote(request.template_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.template_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateCodeTemplateOutput"),
            **kwargs,
        )

    def DeleteCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates/"+urllib.parse.quote(request.template_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.template_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteCodeTemplateOutput"),
            **kwargs,
        )

    def ListCodeTemplates(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListCodeTemplatesOutput"),
            **kwargs,
        )

    def DescribeCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/templates/"+urllib.parse.quote(request.template_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.template_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeCodeTemplateOutput"),
            **kwargs,
        )

    def LookupCodeTemplate(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/template"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.LookupCodeTemplateOutput"),
            **kwargs,
        )

    def CreateAttachment(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateAttachmentOutput"),
            **kwargs,
        )

    def UpdateAttachment(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments/"+urllib.parse.quote(request.attachment_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.attachment_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateAttachmentOutput"),
            **kwargs,
        )

    def DeleteAttachment(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments/"+urllib.parse.quote(request.attachment_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.attachment_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteAttachmentOutput"),
            **kwargs,
        )

    def ListAttachments(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListAttachmentsOutput"),
            **kwargs,
        )

    def DescribeAttachment(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/attachments/"+urllib.parse.quote(request.attachment_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.attachment_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeAttachmentOutput"),
            **kwargs,
        )

    def ListVersions(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/versions"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListVersionsOutput"),
            **kwargs,
        )

    def ListProblemTop(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/top"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListProblemTopOutput"),
            **kwargs,
        )

    def DescribeProblemGrading(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/grading"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeProblemGradingOutput"),
            **kwargs,
        )

    def CreateSubmission(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/submissions"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateSubmissionOutput"),
            **kwargs,
        )

    def DescribeSubmission(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/submissions/"+urllib.parse.quote(request.submission_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.submission_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeSubmissionOutput"),
            **kwargs,
        )

    def RetestSubmission(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/submissions/"+urllib.parse.quote(request.submission_id)+"/retest"

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.submission_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.RetestSubmissionOutput"),
            **kwargs,
        )

    def ListSubmissions(self, request, **kwargs):
        path = "/submissions"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListSubmissionsOutput"),
            **kwargs,
        )

    def DescribeScore(self, request, **kwargs):
        path = "/problems/"+urllib.parse.quote(request.problem_id)+"/scores/"+urllib.parse.quote(request.member_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.problem_id = ""
        request.member_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeScoreOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class NewsletterServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribeNewsletter(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DescribeNewsletterOutput"),
            **kwargs,
        )

    def ListNewsletters(self, request, **kwargs):
        path = "/newsletter"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.ListNewslettersOutput"),
            **kwargs,
        )

    def CreateNewsletter(self, request, **kwargs):
        path = "/newsletter"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.CreateNewsletterOutput"),
            **kwargs,
        )

    def UpdateNewsletter(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.UpdateNewsletterOutput"),
            **kwargs,
        )

    def DeleteNewsletter(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DeleteNewsletterOutput"),
            **kwargs,
        )

    def SendNewsletter(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)+"/send"

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.SendNewsletterOutput"),
            **kwargs,
        )

    def TestNewsletter(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)+"/test"

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.TestNewsletterOutput"),
            **kwargs,
        )

    def DescribeNewsletterTranslation(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DescribeNewsletterTranslationOutput"),
            **kwargs,
        )

    def ListNewsletterTranslations(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.ListNewsletterTranslationsOutput"),
            **kwargs,
        )

    def CreateNewsletterTranslation(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.CreateNewsletterTranslationOutput"),
            **kwargs,
        )

    def UpdateNewsletterTranslation(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.UpdateNewsletterTranslationOutput"),
            **kwargs,
        )

    def DeleteNewsletterTranslation(self, request, **kwargs):
        path = "/newsletter/"+urllib.parse.quote(request.newsletter_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.newsletter_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.newsletter.DeleteNewsletterTranslationOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/keeper/keeper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/keeper/keeper.proto\x12\reolymp.keeper\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"!\n\x11\x43reateObjectInput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"S\n\x12\x43reateObjectOutput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08\x62lob_ern\x18\x02 \x01(\t\x12\x11\n\tblob_hash\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\"\n\x13\x44\x65scribeObjectInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"$\n\x14\x44\x65scribeObjectOutput\x12\x0c\n\x04size\x18\x01 \x01(\x05\"@\n\x13\x44ownloadObjectInput\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"2\n\x14\x44ownloadObjectOutput\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04size\x18\x02 \x01(\x05\"\x1b\n\x19StartMultipartUploadInput\"B\n\x1aStartMultipartUploadOutput\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\tupload_id\x18\x02 \x01(\t\"Z\n\x0fUploadPartInput\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\tupload_id\x18\x02 \x01(\t\x12\x13\n\x0bpart_number\x18\x03 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\n \x01(\x0c\" \n\x10UploadPartOutput\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\"\xc2\x01\n\x1c\x43ompleteMultipartUploadInput\x12\x11\n\tobject_id\x18\x01 \x01(\t\x12\x11\n\tupload_id\x18\x02 \x01(\t\x12?\n\x05parts\x18\n \x03(\x0b\x32\x30.eolymp.keeper.CompleteMultipartUploadInput.Part\x1a;\n\x04Part\x12\x0e\n\x06number\x18\x01 \x01(\r\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x15\n\rchecksum_sha1\x18\n \x01(\t\"\x1f\n\x1d\x43ompleteMultipartUploadOutput2\xec\x07\n\x06Keeper\x12\x90\x01\n\x0c\x43reateObject\x12 .eolymp.keeper.CreateObjectInput\x1a!.eolymp.keeper.CreateObjectOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\n\"\x08/objects\x12\x9b\x01\n\x0e\x44\x65scribeObject\x12\".eolymp.keeper.DescribeObjectInput\x1a#.eolymp.keeper.DescribeObjectOutput\"@\x82\xe3\n\x16\x8a\xe3\n\x12keeper:object:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x10\x12\x0e/objects/{key}\x12\xa0\x01\n\x0e\x44ownloadObject\x12\".eolymp.keeper.DownloadObjectInput\x1a#.eolymp.keeper.DownloadObjectOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12keeper:object:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x15\x12\x13/objects/{key}/data\x12\xa7\x01\n\x14StartMultipartUpload\x12(.eolymp.keeper.StartMultipartUploadInput\x1a).eolymp.keeper.StartMultipartUploadOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\"\x08/uploads\x12\x9b\x01\n\nUploadPart\x12\x1e.eolymp.keeper.UploadPartInput\x1a\x1f.eolymp.keeper.UploadPartOutput\"L\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1c\"\x1a/objects/{object_id}/parts\x12\xc5\x01\n\x17\x43ompleteMultipartUpload\x12+.eolymp.keeper.CompleteMultipartUploadInput\x1a,.eolymp.keeper.CompleteMultipartUploadOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13keeper:object:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1f\"\x1d/objects/{object_id}/completeB/Z-github.com/eolymp/go-sdk/eolymp/keeper;keeperb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.keeper.keeper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/keeper;keeper'
  _KEEPER.methods_by_name['CreateObject']._options = None
  _KEEPER.methods_by_name['CreateObject']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\014\365\342\n\000\000\000@\370\342\n\364\003\202\323\344\223\002\n\"\010/objects'
  _KEEPER.methods_by_name['DescribeObject']._options = None
  _KEEPER.methods_by_name['DescribeObject']._serialized_options = b'\202\343\n\026\212\343\n\022keeper:object:read\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\020\022\016/objects/{key}'
  _KEEPER.methods_by_name['DownloadObject']._options = None
  _KEEPER.methods_by_name['DownloadObject']._serialized_options = b'\202\343\n\026\212\343\n\022keeper:object:read\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\025\022\023/objects/{key}/data'
  _KEEPER.methods_by_name['StartMultipartUpload']._options = None
  _KEEPER.methods_by_name['StartMultipartUpload']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\n\"\010/uploads'
  _KEEPER.methods_by_name['UploadPart']._options = None
  _KEEPER.methods_by_name['UploadPart']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\034\"\032/objects/{object_id}/parts'
  _KEEPER.methods_by_name['CompleteMultipartUpload']._options = None
  _KEEPER.methods_by_name['CompleteMultipartUpload']._serialized_options = b'\202\343\n\027\212\343\n\023keeper:object:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\037\"\035/objects/{object_id}/complete'
  _CREATEOBJECTINPUT._serialized_start=144
  _CREATEOBJECTINPUT._serialized_end=177
  _CREATEOBJECTOUTPUT._serialized_start=179
  _CREATEOBJECTOUTPUT._serialized_end=262
  _DESCRIBEOBJECTINPUT._serialized_start=264
  _DESCRIBEOBJECTINPUT._serialized_end=298
  _DESCRIBEOBJECTOUTPUT._serialized_start=300
  _DESCRIBEOBJECTOUTPUT._serialized_end=336
  _DOWNLOADOBJECTINPUT._serialized_start=338
  _DOWNLOADOBJECTINPUT._serialized_end=402
  _DOWNLOADOBJECTOUTPUT._serialized_start=404
  _DOWNLOADOBJECTOUTPUT._serialized_end=454
  _STARTMULTIPARTUPLOADINPUT._serialized_start=456
  _STARTMULTIPARTUPLOADINPUT._serialized_end=483
  _STARTMULTIPARTUPLOADOUTPUT._serialized_start=485
  _STARTMULTIPARTUPLOADOUTPUT._serialized_end=551
  _UPLOADPARTINPUT._serialized_start=553
  _UPLOADPARTINPUT._serialized_end=643
  _UPLOADPARTOUTPUT._serialized_start=645
  _UPLOADPARTOUTPUT._serialized_end=677
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_start=680
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_end=874
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_start=815
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_end=874
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_start=876
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_end=907
  _KEEPER._serialized_start=910
  _KEEPER._serialized_end=1914
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Checker(_message.Message):
    __slots__ = ["case_sensitive", "files", "lang", "order_sensitive", "precision", "secret", "source", "source_url", "type"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class File(_message.Message):
        __slots__ = ["path", "source_url"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
        path: str
        source_url: str
        def __init__(self, path: _Optional[str] = ..., source_url: _Optional[str] = ...) -> None: ...
    CASE_SENSITIVE_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    LANG_FIELD_NUMBER: _ClassVar[int]
    LEGACY_PROGRAM: Checker.Type
    LINES: Checker.Type
    NONE: Checker.Type
    ORDER_SENSITIVE_FIELD_NUMBER: _ClassVar[int]
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    PROGRAM: Checker.Type
    QUERY_RESULTS: Checker.Type
    SECRET_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    TOKENS: Checker.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    case_sensitive: bool
    files: _containers.RepeatedCompositeFieldContainer[Checker.File]
    lang: str
    order_sensitive: bool
    precision: int
    secret: bool
    source: str
    source_url: str
    type: Checker.Type
    def __init__(self, type: _Optional[_Union[Checker.Type, str]] = ..., lang: _Optional[str] = ..., source: _Optional[str] = ..., source_url: _Optional[str] = ..., precision: _Optional[int] = ..., case_sensitive: bool = ..., order_sensitive: bool = ..., secret: bool = ..., files: _Optional[_Iterable[_Union[Checker.File, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.taxonomy import enum_pb2 as _enum_pb2
from eolymp.taxonomy import enum_value_pb2 as _enum_value_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateEnumInput(_message.Message):
    __slots__ = ["enum"]
    ENUM_FIELD_NUMBER: _ClassVar[int]
    enum: _enum_pb2.Enum
    def __init__(self, enum: _Optional[_Union[_enum_pb2.Enum, _Mapping]] = ...) -> None: ...

class CreateEnumOutput(_message.Message):
    __slots__ = ["enum_id"]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    def __init__(self, enum_id: _Optional[str] = ...) -> None: ...

class CreateValueInput(_message.Message):
    __slots__ = ["enum_id", "value"]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    value: _enum_value_pb2.Value
    def __init__(self, enum_id: _Optional[str] = ..., value: _Optional[_Union[_enum_value_pb2.Value, _Mapping]] = ...) -> None: ...

class CreateValueOutput(_message.Message):
    __slots__ = ["value_id"]
    VALUE_ID_FIELD_NUMBER: _ClassVar[int]
    value_id: str
    def __init__(self, value_id: _Optional[str] = ...) -> None: ...

class DeleteEnumInput(_message.Message):
    __slots__ = ["enum_id"]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    def __init__(self, enum_id: _Optional[str] = ...) -> None: ...

class DeleteEnumOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteTranslationInput(_message.Message):
    __slots__ = ["enum_id", "locale", "value_id"]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    VALUE_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    locale: str
    value_id: str
    def __init__(self, enum_id: _Optional[str] = ..., value_id: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class DeleteTranslationOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteValueInput(_message.Message):
    __slots__ = ["enum_id", "value_id"]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    value_id: str
    def __init__(self, enum_id: _Optional[str] = ..., value_id: _Optional[str] = ...) -> None: ...

class DeleteValueOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeEnumInput(_message.Message):
    __slots__ = ["enum_id"]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    def __init__(self, enum_id: _Optional[str] = ...) -> None: ...

class DescribeEnumOutput(_message.Message):
    __slots__ = ["enum"]
    ENUM_FIELD_NUMBER: _ClassVar[int]
    enum: _enum_pb2.Enum
    def __init__(self, enum: _Optional[_Union[_enum_pb2.Enum, _Mapping]] = ...) -> None: ...

class DescribeValueInput(_message.Message):
    __slots__ = ["enum_id", "locale", "value_id"]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    VALUE_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    locale: str
    value_id: str
    def __init__(self, enum_id: _Optional[str] = ..., value_id: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class DescribeValueOutput(_message.Message):
    __slots__ = ["value"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: _enum_value_pb2.Value
    def __init__(self, value: _Optional[_Union[_enum_value_pb2.Value, _Mapping]] = ...) -> None: ...

class ListEnumsInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "name", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListEnumsInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListEnumsInput.Filter, _Mapping]] = ...) -> None: ...

class ListEnumsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_enum_pb2.Enum]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_enum_pb2.Enum, _Mapping]]] = ...) -> None: ...

class ListTranslationsInput(_message.Message):
    __slots__ = ["enum_id", "filters", "offset", "size", "value_id"]
    class Filter(_message.Message):
        __slots__ = ["locale"]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    VALUE_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    filters: ListTranslationsInput.Filter
    offset: int
    size: int
    value_id: str
    def __init__(self, enum_id: _Optional[str] = ..., value_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListTranslationsInput.Filter, _Mapping]] = ...) -> None: ...

class ListTranslationsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_enum_value_pb2.Value.Translation]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_enum_value_pb2.Value.Translation, _Mapping]]] = ...) -> None: ...

class ListValuesInput(_message.Message):
    __slots__ = ["enum_id", "filters", "locale", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "name", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    filters: ListValuesInput.Filter
    locale: str
    offset: int
    size: int
    def __init__(self, enum_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListValuesInput.Filter, _Mapping]] = ..., locale: _Optional[str] = ...) -> None: ...

class ListValuesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_enum_value_pb2.Value]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_enum_value_pb2.Value, _Mapping]]] = ...) -> None: ...

class TranslateValueInput(_message.Message):
    __slots__ = ["enum_id", "locale", "translation", "value_id"]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    VALUE_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    locale: str
    translation: _enum_value_pb2.Value.Translation
    value_id: str
    def __init__(self, enum_id: _Optional[str] = ..., value_id: _Optional[str] = ..., locale: _Optional[str] = ..., translation: _Optional[_Union[_enum_value_pb2.Value.Translation, _Mapping]] = ...) -> None: ...

class TranslateValueOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateEnumInput(_message.Message):
    __slots__ = ["enum", "enum_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateEnumInput.Patch
    ENUM_FIELD_NUMBER: _ClassVar[int]
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    NAME: UpdateEnumInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    enum: _enum_pb2.Enum
    enum_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateEnumInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateEnumInput.Patch, str]]] = ..., enum_id: _Optional[str] = ..., enum: _Optional[_Union[_enum_pb2.Enum, _Mapping]] = ...) -> None: ...

class UpdateEnumOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateValueInput(_message.Message):
    __slots__ = ["enum_id", "patch", "value", "value_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ABBR: UpdateValueInput.Patch
    ALL: UpdateValueInput.Patch
    ENUM_ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE: UpdateValueInput.Patch
    KEYWORDS: UpdateValueInput.Patch
    NAME: UpdateValueInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    SUMMARY: UpdateValueInput.Patch
    VALUE_FIELD_NUMBER: _ClassVar[int]
    VALUE_ID_FIELD_NUMBER: _ClassVar[int]
    enum_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateValueInput.Patch]
    value: _enum_value_pb2.Value
    value_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateValueInput.Patch, str]]] = ..., enum_id: _Optional[str] = ..., value_id: _Optional[str] = ..., value: _Optional[_Union[_enum_value_pb2.Value, _Mapping]] = ...) -> None: ...

class UpdateValueOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/attribute_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/community/attribute_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/community/attribute.proto\x1a!eolymp/wellknown/expression.proto\"]\n\x14\x43reateAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x17\n\x15\x43reateAttributeOutput\"]\n\x14UpdateAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12.\n\tattribute\x18\x02 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\x17\n\x15UpdateAttributeOutput\"-\n\x14RemoveAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"\x17\n\x15RemoveAttributeOutput\"/\n\x16\x44\x65scribeAttributeInput\x12\x15\n\rattribute_key\x18\x01 \x01(\t\"I\n\x17\x44\x65scribeAttributeOutput\x12.\n\tattribute\x18\x01 \x01(\x0b\x32\x1b.eolymp.community.Attribute\"\xee\x02\n\x13ListAttributesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.community.ListAttributesInput.Filter\x1a\xf9\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03key\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06hidden\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08required\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04type\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Q\n\x14ListAttributesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.community.Attribute2\x95\x07\n\x10\x41ttributeService\x12\xa7\x01\n\x0f\x43reateAttribute\x12&.eolymp.community.CreateAttributeInput\x1a\'.eolymp.community.CreateAttributeOutput\"C\x82\xe3\n\x1d\x8a\xe3\n\x19\x63ommunity:attribute:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\r\"\x0b/attributes\x12\xb7\x01\n\x0fUpdateAttribute\x12&.eolymp.community.UpdateAttributeInput\x1a\'.eolymp.community.UpdateAttributeOutput\"S\x82\xe3\n\x1d\x8a\xe3\n\x19\x63ommunity:attribute:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\"\x1b/attributes/{attribute_key}\x12\xb7\x01\n\x0fRemoveAttribute\x12&.eolymp.community.RemoveAttributeInput\x1a\'.eolymp.community.RemoveAttributeOutput\"S\x82\xe3\n\x1d\x8a\xe3\n\x19\x63ommunity:attribute:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d*\x1b/attributes/{attribute_key}\x12\xbc\x01\n\x11\x44\x65scribeAttribute\x12(.eolymp.community.DescribeAttributeInput\x1a).eolymp.community.DescribeAttributeOutput\"R\x82\xe3\n\x1c\x8a\xe3\n\x18\x63ommunity:attribute:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1d\x12\x1b/attributes/{attribute_key}\x12\xa3\x01\n\x0eListAttributes\x12%.eolymp.community.ListAttributesInput\x1a&.eolymp.community.ListAttributesOutput\"B\x82\xe3\n\x1c\x8a\xe3\n\x18\x63ommunity:attribute:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\r\x12\x0b/attributesB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.attribute_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _ATTRIBUTESERVICE.methods_by_name['CreateAttribute']._options = None
  _ATTRIBUTESERVICE.methods_by_name['CreateAttribute']._serialized_options = b'\202\343\n\035\212\343\n\031community:attribute:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\r\"\013/attributes'
  _ATTRIBUTESERVICE.methods_by_name['UpdateAttribute']._options = None
  _ATTRIBUTESERVICE.methods_by_name['UpdateAttribute']._serialized_options = b'\202\343\n\035\212\343\n\031community:attribute:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\"\033/attributes/{attribute_key}'
  _ATTRIBUTESERVICE.methods_by_name['RemoveAttribute']._options = None
  _ATTRIBUTESERVICE.methods_by_name['RemoveAttribute']._serialized_options = b'\202\343\n\035\212\343\n\031community:attribute:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035*\033/attributes/{attribute_key}'
  _ATTRIBUTESERVICE.methods_by_name['DescribeAttribute']._options = None
  _ATTRIBUTESERVICE.methods_by_name['DescribeAttribute']._serialized_options = b'\202\343\n\034\212\343\n\030community:attribute:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\035\022\033/attributes/{attribute_key}'
  _ATTRIBUTESERVICE.methods_by_name['ListAttributes']._options = None
  _ATTRIBUTESERVICE.methods_by_name['ListAttributes']._serialized_options = b'\202\343\n\034\212\343\n\030community:attribute:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\r\022\013/attributes'
  _CREATEATTRIBUTEINPUT._serialized_start=230
  _CREATEATTRIBUTEINPUT._serialized_end=323
  _CREATEATTRIBUTEOUTPUT._serialized_start=325
  _CREATEATTRIBUTEOUTPUT._serialized_end=348
  _UPDATEATTRIBUTEINPUT._serialized_start=350
  _UPDATEATTRIBUTEINPUT._serialized_end=443
  _UPDATEATTRIBUTEOUTPUT._serialized_start=445
  _UPDATEATTRIBUTEOUTPUT._serialized_end=468
  _REMOVEATTRIBUTEINPUT._serialized_start=470
  _REMOVEATTRIBUTEINPUT._serialized_end=515
  _REMOVEATTRIBUTEOUTPUT._serialized_start=517
  _REMOVEATTRIBUTEOUTPUT._serialized_end=540
  _DESCRIBEATTRIBUTEINPUT._serialized_start=542
  _DESCRIBEATTRIBUTEINPUT._serialized_end=589
  _DESCRIBEATTRIBUTEOUTPUT._serialized_start=591
  _DESCRIBEATTRIBUTEOUTPUT._serialized_end=664
  _LISTATTRIBUTESINPUT._serialized_start=667
  _LISTATTRIBUTESINPUT._serialized_end=1033
  _LISTATTRIBUTESINPUT_FILTER._serialized_start=784
  _LISTATTRIBUTESINPUT_FILTER._serialized_end=1033
  _LISTATTRIBUTESOUTPUT._serialized_start=1035
  _LISTATTRIBUTESOUTPUT._serialized_end=1116
  _ATTRIBUTESERVICE._serialized_start=1119
  _ATTRIBUTESERVICE._serialized_end=2036
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Price(_message.Message):
    __slots__ = ["currency", "id", "recurrence", "unit_amount"]
    class Recurrence(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MONTHLY: Price.Recurrence
    ONETIME: Price.Recurrence
    RECURRENCE_FIELD_NUMBER: _ClassVar[int]
    UNIT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_RECURRENCE: Price.Recurrence
    YEARLY: Price.Recurrence
    currency: str
    id: str
    recurrence: Price.Recurrence
    unit_amount: int
    def __init__(self, id: _Optional[str] = ..., recurrence: _Optional[_Union[Price.Recurrence, str]] = ..., currency: _Optional[str] = ..., unit_amount: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Video(_message.Message):
    __slots__ = ["duration", "image_url", "video_url"]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    VIDEO_URL_FIELD_NUMBER: _ClassVar[int]
    duration: int
    image_url: str
    video_url: str
    def __init__(self, image_url: _Optional[str] = ..., video_url: _Optional[str] = ..., duration: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/wellknown/direction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/wellknown/direction.proto\x12\x10\x65olymp.wellknown*\x1e\n\tDirection\x12\x07\n\x03\x41SC\x10\x00\x12\x08\n\x04\x44\x45SC\x10\x01\x42\x35Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknownb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.wellknown.direction_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknown'
  _DIRECTION._serialized_start=54
  _DIRECTION._serialized_end=84
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.cognito import user_pb2 as eolymp_dot_cognito_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/cognito/events.proto\x12\x0e\x65olymp.cognito\x1a\x19\x65olymp/cognito/user.proto\"]\n\x10UserChangedEvent\x12$\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\x12#\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x14.eolymp.cognito.UserB1Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _USERCHANGEDEVENT._serialized_start=74
  _USERCHANGEDEVENT._serialized_end=167
# @@protoc_insertion_point(module_scope)
